# /etc/cron.d/barman: crontab entries for the barman package
MAILTO=root
# On systemd, barman.timer already runs "barman cron"; run from cron only when
# systemd is not the init system, to avoid executing it twice.
* * * * * barman test -d /run/systemd/system || { [ -x /usr/bin/barman ] && /usr/bin/barman -q cron; }
